DartCMS
=======

DartCMS is an open-source content management system based on the popular Django Framework. It's friendly for developers
and end-users.


Features
--------

- Tree-like website page structure
- Fast and easy CMS module developing
- Built with Twitter Bootstrap 3
- TinyMCE as rich editor
- Custom file manager to work with TinyMCE


Modules
-------

At the moment, these modules are included:

- Site Structure
- CMS Users
- Site Settings
- News and Articles
- Advertising (ads, ad places and ad sections)
- Feedback and FAQ
- E-shop. With product categories, sections etc


Installation
------------

You can install DartCMS with `pip`:

`pip install dartcms`


Documentation
-------------

Documentation can be found here - http://dartcms.readthedocs.io/
